@@ -170,14 +170,15 @@ for TAI/UTC conversion.)
 
 package Date::JD;
 
+{ use 5.006; }
 use warnings;
 use strict;
 
 use Carp qw(croak);
 
-our $VERSION = "0.003";
+our $VERSION = "0.004";
 
-use base qw(Exporter);
+use parent "Exporter";
 our @EXPORT_OK;
 
 my %jd_flavours = (
@@ -860,7 +861,8 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006, 2007, 2009 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2006, 2007, 2009, 2010
+Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 LICENSE
 
